//
// C++ Implementation: aptsearchpluginshortinputwidget
//
// Description: 
//
//
// Author: Benjamin Mesing <bensmail@gmx.net>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "aptsearchpluginshortinputwidget.h"

AptSearchPluginShortInputWidget::AptSearchPluginShortInputWidget(QWidget *parent, const char *name)
 : QWidget(parent)
{
	setupUi(this);
	setObjectName(name);
}


AptSearchPluginShortInputWidget::~AptSearchPluginShortInputWidget()
{
}

void AptSearchPluginShortInputWidget::setClearButton( QPushButton * pButton, int)
{
	delete(_pClearButton);
	_pClearButton = pButton;
#warning reenable adding of clear button
	// first add a new layout, to hold the new clear button
	QLayout* pLayout = new QHBoxLayout;
	layout()->addItem(pLayout);
	pLayout->setMargin(0);
	pLayout->setSpacing(2);
	pLayout->addWidget(_pClearButton);
	pLayout->addWidget(_pAptSearchTextInput);
	
	// second reaadd the items in the layout below, to remain the order correctly
	pLayout = new QHBoxLayout;
	layout()->addItem(pLayout);
	pLayout->setMargin(0);
	pLayout->setSpacing(6);
	pLayout->addWidget(_pSearchDescriptionsCheck);
	pLayout->addWidget(_pCaseSensitiveCheck);
// TODO QT3to4 porting - commented out - reimplement
//	_pInputLayout->insertWidget(index, pButton);
}

